@@ -24,20 +24,24 @@
 /*----------------------------------------------------------------------------*/
 /* Prototype                                                                  */
 /*----------------------------------------------------------------------------*/
-extern char* chxj_encoding(
-  request_rec*       r, 
-  const char*        src, 
-  apr_size_t*        len);
+extern char *chxj_encoding(
+  request_rec *r, 
+  const char  *src, 
+  apr_size_t  *len);
 
-extern char* chxj_rencoding(
-  request_rec*       r, 
-  const char*        src, 
-  apr_size_t*        len);
+extern char *chxj_rencoding(
+  request_rec *r, 
+  const char *src, 
+  apr_size_t *len,
+  const char *enc);
 
-extern char* chxj_encoding_parameter(
-  request_rec*       r, 
-  const char*        value);
+extern char *chxj_encoding_parameter(
+  request_rec *r, 
+  const char  *value,
+  int xmlflag);
 
+
+char *chxj_iconv(request_rec *r, apr_pool_t *pool, const char *src, apr_size_t *len, const char *from, const char *to);
 extern void
 chxj_convert_illegal_charactor_sequence(
   request_rec         *r,
